/* moonshot-settings.c generated by valac 0.34.9, the Vala compiler
 * generated from moonshot-settings.vala, do not modify */

/*
 * Copyright (c) 2011-2016, JANET(UK)
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * 3. Neither the name of JANET(UK) nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
*/

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <gio/gio.h>


#define TYPE_MOONSHOT_LOGGER (moonshot_logger_get_type ())
#define MOONSHOT_LOGGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MOONSHOT_LOGGER, MoonshotLogger))
#define MOONSHOT_LOGGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MOONSHOT_LOGGER, MoonshotLoggerClass))
#define IS_MOONSHOT_LOGGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MOONSHOT_LOGGER))
#define IS_MOONSHOT_LOGGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MOONSHOT_LOGGER))
#define MOONSHOT_LOGGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MOONSHOT_LOGGER, MoonshotLoggerClass))

typedef struct _MoonshotLogger MoonshotLogger;
typedef struct _MoonshotLoggerClass MoonshotLoggerClass;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_key_file_unref0(var) ((var == NULL) ? NULL : (var = (g_key_file_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))



GType moonshot_logger_get_type (void) G_GNUC_CONST;
MoonshotLogger* logger (void);
MoonshotLogger* get_logger (const gchar* name);
#define KEY_FILE_NAME "moonshot-ui.config"
GKeyFile* get_keyfile (void);
void moonshot_logger_trace (MoonshotLogger* self, const gchar* message, GError* e);
void save_keyfile (GKeyFile* key_file);
void moonshot_logger_error (MoonshotLogger* self, const gchar* message, GError* e);
void set_bool_setting (const gchar* group_name, const gchar* key_name, gboolean value, GKeyFile* key_file);
gboolean get_bool_setting (const gchar* group_name, const gchar* key_name, gboolean _default_, GKeyFile* key_file);
void moonshot_logger_info (MoonshotLogger* self, const gchar* message, GError* e);
void set_string_setting (const gchar* group_name, const gchar* key_name, const gchar* value, GKeyFile* key_file);
gchar* get_string_setting (const gchar* group_name, const gchar* key_name, const gchar* _default_, GKeyFile* key_file);


MoonshotLogger* logger (void) {
	MoonshotLogger* result = NULL;
	MoonshotLogger* _tmp0_ = NULL;
#line 38 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	_tmp0_ = get_logger ("MoonshotSettings");
#line 38 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	result = _tmp0_;
#line 38 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	return result;
#line 84 "moonshot-settings.c"
}


GKeyFile* get_keyfile (void) {
	GKeyFile* result = NULL;
	GKeyFile* key_file = NULL;
	GKeyFile* _tmp0_ = NULL;
	gchar* config_dir = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	MoonshotLogger* _tmp3_ = NULL;
	MoonshotLogger* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	GFile* dir = NULL;
	const gchar* _tmp8_ = NULL;
	GFile* _tmp9_ = NULL;
	gchar* path = NULL;
	GFile* _tmp10_ = NULL;
	GFile* _tmp11_ = NULL;
	GFile* _tmp12_ = NULL;
	gchar* _tmp13_ = NULL;
	gchar* _tmp14_ = NULL;
	GError * _inner_error_ = NULL;
#line 45 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	_tmp0_ = g_key_file_new ();
#line 45 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	key_file = _tmp0_;
#line 46 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	_tmp1_ = g_get_user_config_dir ();
#line 46 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 46 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	config_dir = _tmp2_;
#line 47 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	_tmp3_ = logger ();
#line 47 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	_tmp4_ = _tmp3_;
#line 47 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	_tmp5_ = config_dir;
#line 47 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	_tmp6_ = g_strconcat ("get_keyfile: config_dir=", _tmp5_, NULL);
#line 47 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	_tmp7_ = _tmp6_;
#line 47 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	moonshot_logger_trace (_tmp4_, _tmp7_, NULL);
#line 47 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	_g_free0 (_tmp7_);
#line 47 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	_g_object_unref0 (_tmp4_);
#line 49 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	_tmp8_ = config_dir;
#line 49 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	_tmp9_ = g_file_new_for_path (_tmp8_);
#line 49 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	dir = _tmp9_;
#line 50 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	_tmp10_ = dir;
#line 50 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	_tmp11_ = g_file_get_child (_tmp10_, KEY_FILE_NAME);
#line 50 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	_tmp12_ = _tmp11_;
#line 50 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	_tmp13_ = g_file_get_path (_tmp12_);
#line 50 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	_tmp14_ = _tmp13_;
#line 50 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	_g_object_unref0 (_tmp12_);
#line 50 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	path = _tmp14_;
#line 156 "moonshot-settings.c"
	{
		gboolean _tmp15_ = FALSE;
		GKeyFile* _tmp16_ = NULL;
		const gchar* _tmp17_ = NULL;
		gboolean _tmp18_ = FALSE;
#line 53 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp16_ = key_file;
#line 53 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp17_ = path;
#line 53 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp18_ = g_key_file_load_from_file (_tmp16_, _tmp17_, G_KEY_FILE_NONE, &_inner_error_);
#line 53 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp15_ = _tmp18_;
#line 53 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 53 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			if (_inner_error_->domain == G_FILE_ERROR) {
#line 174 "moonshot-settings.c"
				goto __catch11_g_file_error;
			}
#line 53 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			if (_inner_error_->domain == G_KEY_FILE_ERROR) {
#line 179 "moonshot-settings.c"
				goto __catch11_g_key_file_error;
			}
#line 53 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			_g_free0 (path);
#line 53 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			_g_object_unref0 (dir);
#line 53 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			_g_free0 (config_dir);
#line 53 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			_g_key_file_unref0 (key_file);
#line 53 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 53 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			g_clear_error (&_inner_error_);
#line 53 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			return NULL;
#line 196 "moonshot-settings.c"
		}
#line 53 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		if (_tmp15_) {
#line 200 "moonshot-settings.c"
			MoonshotLogger* _tmp19_ = NULL;
			MoonshotLogger* _tmp20_ = NULL;
#line 54 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			_tmp19_ = logger ();
#line 54 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			_tmp20_ = _tmp19_;
#line 54 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			moonshot_logger_trace (_tmp20_, "get_keyfile: load_from_file returned successfully", NULL);
#line 54 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			_g_object_unref0 (_tmp20_);
#line 211 "moonshot-settings.c"
		} else {
			MoonshotLogger* _tmp21_ = NULL;
			MoonshotLogger* _tmp22_ = NULL;
#line 56 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			_tmp21_ = logger ();
#line 56 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			_tmp22_ = _tmp21_;
#line 56 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			moonshot_logger_trace (_tmp22_, "get_keyfile: load_from_file returned false", NULL);
#line 56 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			_g_object_unref0 (_tmp22_);
#line 223 "moonshot-settings.c"
		}
	}
	goto __finally11;
	__catch11_g_file_error:
	{
		GError* e = NULL;
		MoonshotLogger* _tmp23_ = NULL;
		MoonshotLogger* _tmp24_ = NULL;
		GError* _tmp25_ = NULL;
		const gchar* _tmp26_ = NULL;
		gchar* _tmp27_ = NULL;
		gchar* _tmp28_ = NULL;
#line 52 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		e = _inner_error_;
#line 52 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_inner_error_ = NULL;
#line 59 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp23_ = logger ();
#line 59 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp24_ = _tmp23_;
#line 59 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp25_ = e;
#line 59 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp26_ = _tmp25_->message;
#line 59 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp27_ = g_strconcat ("get_keyfile: FileError: ", _tmp26_, NULL);
#line 59 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp28_ = _tmp27_;
#line 59 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		moonshot_logger_trace (_tmp24_, _tmp28_, NULL);
#line 59 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_g_free0 (_tmp28_);
#line 59 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_g_object_unref0 (_tmp24_);
#line 52 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_g_error_free0 (e);
#line 260 "moonshot-settings.c"
	}
	goto __finally11;
	__catch11_g_key_file_error:
	{
		GError* e = NULL;
		MoonshotLogger* _tmp29_ = NULL;
		MoonshotLogger* _tmp30_ = NULL;
		GError* _tmp31_ = NULL;
		const gchar* _tmp32_ = NULL;
		gchar* _tmp33_ = NULL;
		gchar* _tmp34_ = NULL;
#line 52 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		e = _inner_error_;
#line 52 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_inner_error_ = NULL;
#line 62 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp29_ = logger ();
#line 62 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp30_ = _tmp29_;
#line 62 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp31_ = e;
#line 62 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp32_ = _tmp31_->message;
#line 62 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp33_ = g_strconcat ("get_keyfile: KeyFileError: ", _tmp32_, NULL);
#line 62 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp34_ = _tmp33_;
#line 62 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		moonshot_logger_trace (_tmp30_, _tmp34_, NULL);
#line 62 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_g_free0 (_tmp34_);
#line 62 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_g_object_unref0 (_tmp30_);
#line 52 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_g_error_free0 (e);
#line 296 "moonshot-settings.c"
	}
	__finally11:
#line 52 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 52 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_g_free0 (path);
#line 52 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_g_object_unref0 (dir);
#line 52 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_g_free0 (config_dir);
#line 52 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_g_key_file_unref0 (key_file);
#line 52 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 52 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		g_clear_error (&_inner_error_);
#line 52 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		return NULL;
#line 315 "moonshot-settings.c"
	}
#line 65 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	result = key_file;
#line 65 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	_g_free0 (path);
#line 65 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	_g_object_unref0 (dir);
#line 65 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	_g_free0 (config_dir);
#line 65 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	return result;
#line 327 "moonshot-settings.c"
}


static guint8* string_get_data (const gchar* self, int* result_length1) {
	guint8* result;
	guint8* res = NULL;
	gint res_length1 = 0;
	gint _res_size_ = 0;
	gint _tmp0_ = 0;
	gint _tmp1_ = 0;
	gint _tmp2_ = 0;
	guint8* _tmp3_ = NULL;
	gint _tmp3__length1 = 0;
	guint8* _tmp4_ = NULL;
	gint _tmp4__length1 = 0;
#line 1406 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1407 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	res = (guint8*) self;
#line 1407 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	res_length1 = -1;
#line 1407 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	_res_size_ = res_length1;
#line 1408 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp0_ = strlen (self);
#line 1408 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp1_ = _tmp0_;
#line 1408 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	res_length1 = (gint) _tmp1_;
#line 1408 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp2_ = res_length1;
#line 1409 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp3_ = res;
#line 1409 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp3__length1 = res_length1;
#line 1409 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp4_ = _tmp3_;
#line 1409 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp4__length1 = _tmp3__length1;
#line 1409 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	if (result_length1) {
#line 1409 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
		*result_length1 = _tmp4__length1;
#line 371 "moonshot-settings.c"
	}
#line 1409 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	result = _tmp4_;
#line 1409 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	return result;
#line 377 "moonshot-settings.c"
}


void save_keyfile (GKeyFile* key_file) {
	gchar* config_dir = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	GFile* dest = NULL;
	gchar* data = NULL;
	GKeyFile* _tmp10_ = NULL;
	gchar* _tmp11_ = NULL;
	GError * _inner_error_ = NULL;
#line 69 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	g_return_if_fail (key_file != NULL);
#line 71 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	_tmp0_ = g_get_user_config_dir ();
#line 71 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 71 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	config_dir = _tmp1_;
#line 72 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	dest = NULL;
#line 400 "moonshot-settings.c"
	{
		GFile* dir = NULL;
		GFile* _tmp2_ = NULL;
		GFile* _tmp3_ = NULL;
#line 76 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp2_ = g_file_new_for_path (config_dir);
#line 76 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		dir = _tmp2_;
#line 77 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp3_ = g_file_get_child (dir, KEY_FILE_NAME);
#line 77 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_g_object_unref0 (dest);
#line 77 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		dest = _tmp3_;
#line 78 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		g_file_make_directory_with_parents (dir, NULL, &_inner_error_);
#line 78 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 78 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			_g_object_unref0 (dir);
#line 421 "moonshot-settings.c"
			goto __catch12_g_error;
		}
#line 75 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_g_object_unref0 (dir);
#line 426 "moonshot-settings.c"
	}
	goto __finally12;
	__catch12_g_error:
	{
		GError* e = NULL;
		MoonshotLogger* _tmp4_ = NULL;
		MoonshotLogger* _tmp5_ = NULL;
		GError* _tmp6_ = NULL;
		const gchar* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
#line 75 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		e = _inner_error_;
#line 75 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_inner_error_ = NULL;
#line 80 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp4_ = logger ();
#line 80 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp5_ = _tmp4_;
#line 80 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp6_ = e;
#line 80 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp7_ = _tmp6_->message;
#line 80 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp8_ = g_strconcat ("save_keyfile: make_directory_with_parents threw error (this is usually" \
" ignorable) : ", _tmp7_, NULL);
#line 80 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp9_ = _tmp8_;
#line 80 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		moonshot_logger_trace (_tmp5_, _tmp9_, NULL);
#line 80 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_g_free0 (_tmp9_);
#line 80 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_g_object_unref0 (_tmp5_);
#line 75 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_g_error_free0 (e);
#line 462 "moonshot-settings.c"
	}
	__finally12:
#line 75 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 75 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_g_object_unref0 (dest);
#line 75 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_g_free0 (config_dir);
#line 75 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 75 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		g_clear_error (&_inner_error_);
#line 75 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		return;
#line 477 "moonshot-settings.c"
	}
#line 87 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	_tmp10_ = key_file;
#line 87 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	_tmp11_ = g_key_file_to_data (_tmp10_, NULL, NULL);
#line 87 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	data = _tmp11_;
#line 485 "moonshot-settings.c"
	{
		MoonshotLogger* _tmp12_ = NULL;
		MoonshotLogger* _tmp13_ = NULL;
		GFile* _tmp14_ = NULL;
		gchar* _tmp15_ = NULL;
		gchar* _tmp16_ = NULL;
		gchar* _tmp17_ = NULL;
		gchar* _tmp18_ = NULL;
		gchar* new_etag = NULL;
		GFile* _tmp19_ = NULL;
		guint8* _tmp20_ = NULL;
		gint _tmp20__length1 = 0;
		guint8* _tmp21_ = NULL;
		gint _tmp21__length1 = 0;
		gchar* _tmp22_ = NULL;
#line 89 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp12_ = logger ();
#line 89 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp13_ = _tmp12_;
#line 89 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp14_ = dest;
#line 89 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp15_ = g_file_get_path (_tmp14_);
#line 89 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp16_ = _tmp15_;
#line 89 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp17_ = g_strdup_printf ("save_keyfile: saving to file path '%s'", _tmp16_);
#line 89 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp18_ = _tmp17_;
#line 89 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		moonshot_logger_trace (_tmp13_, _tmp18_, NULL);
#line 89 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_g_free0 (_tmp18_);
#line 89 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_g_free0 (_tmp16_);
#line 89 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_g_object_unref0 (_tmp13_);
#line 94 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp19_ = dest;
#line 94 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp20_ = string_get_data (data, &_tmp20__length1);
#line 94 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp21_ = _tmp20_;
#line 94 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp21__length1 = _tmp20__length1;
#line 94 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		g_file_replace_contents (_tmp19_, _tmp21_, (gsize) _tmp21__length1, NULL, FALSE, G_FILE_CREATE_REPLACE_DESTINATION | G_FILE_CREATE_PRIVATE, &_tmp22_, NULL, &_inner_error_);
#line 94 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_g_free0 (new_etag);
#line 94 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		new_etag = _tmp22_;
#line 94 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 94 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			_g_free0 (new_etag);
#line 541 "moonshot-settings.c"
			goto __catch13_g_error;
		}
#line 88 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_g_free0 (new_etag);
#line 546 "moonshot-settings.c"
	}
	goto __finally13;
	__catch13_g_error:
	{
		GError* e = NULL;
		MoonshotLogger* _tmp23_ = NULL;
		MoonshotLogger* _tmp24_ = NULL;
		GError* _tmp25_ = NULL;
		const gchar* _tmp26_ = NULL;
		gchar* _tmp27_ = NULL;
		gchar* _tmp28_ = NULL;
#line 88 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		e = _inner_error_;
#line 88 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_inner_error_ = NULL;
#line 97 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp23_ = logger ();
#line 97 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp24_ = _tmp23_;
#line 97 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp25_ = e;
#line 97 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp26_ = _tmp25_->message;
#line 97 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp27_ = g_strconcat ("save_keyfile: error when writing to file: ", _tmp26_, NULL);
#line 97 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp28_ = _tmp27_;
#line 97 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		moonshot_logger_error (_tmp24_, _tmp28_, NULL);
#line 97 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_g_free0 (_tmp28_);
#line 97 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_g_object_unref0 (_tmp24_);
#line 88 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_g_error_free0 (e);
#line 582 "moonshot-settings.c"
	}
	__finally13:
#line 88 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 88 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_g_free0 (data);
#line 88 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_g_object_unref0 (dest);
#line 88 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_g_free0 (config_dir);
#line 88 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 88 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		g_clear_error (&_inner_error_);
#line 88 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		return;
#line 599 "moonshot-settings.c"
	}
#line 69 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	_g_free0 (data);
#line 69 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	_g_object_unref0 (dest);
#line 69 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	_g_free0 (config_dir);
#line 607 "moonshot-settings.c"
}


void set_bool_setting (const gchar* group_name, const gchar* key_name, gboolean value, GKeyFile* key_file) {
	GKeyFile* tmp_key_file = NULL;
	GKeyFile* _tmp0_ = NULL;
	GKeyFile* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	gboolean _tmp6_ = FALSE;
	GKeyFile* _tmp7_ = NULL;
#line 103 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	g_return_if_fail (group_name != NULL);
#line 103 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	g_return_if_fail (key_name != NULL);
#line 105 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	tmp_key_file = NULL;
#line 106 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	_tmp0_ = key_file;
#line 106 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	if (_tmp0_ == NULL) {
#line 629 "moonshot-settings.c"
		GKeyFile* _tmp1_ = NULL;
		GKeyFile* _tmp2_ = NULL;
#line 108 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp1_ = get_keyfile ();
#line 108 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_g_key_file_unref0 (tmp_key_file);
#line 108 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		tmp_key_file = _tmp1_;
#line 109 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp2_ = tmp_key_file;
#line 109 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		key_file = _tmp2_;
#line 642 "moonshot-settings.c"
	}
#line 112 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	_tmp3_ = key_file;
#line 112 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	_tmp4_ = group_name;
#line 112 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	_tmp5_ = key_name;
#line 112 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	_tmp6_ = value;
#line 112 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	g_key_file_set_boolean (_tmp3_, _tmp4_, _tmp5_, _tmp6_);
#line 114 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	_tmp7_ = tmp_key_file;
#line 114 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	if (_tmp7_ != NULL) {
#line 658 "moonshot-settings.c"
		GKeyFile* _tmp8_ = NULL;
#line 116 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp8_ = key_file;
#line 116 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		save_keyfile (_tmp8_);
#line 664 "moonshot-settings.c"
	}
#line 103 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	_g_key_file_unref0 (tmp_key_file);
#line 668 "moonshot-settings.c"
}


static const gchar* string_to_string (const gchar* self) {
	const gchar* result = NULL;
#line 1420 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1421 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	result = self;
#line 1421 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	return result;
#line 680 "moonshot-settings.c"
}


gboolean get_bool_setting (const gchar* group_name, const gchar* key_name, gboolean _default_, GKeyFile* key_file) {
	gboolean result = FALSE;
	GKeyFile* tmp_key_file = NULL;
	GKeyFile* _tmp0_ = NULL;
	GKeyFile* _tmp3_ = NULL;
	gboolean _tmp46_ = FALSE;
	GError * _inner_error_ = NULL;
#line 120 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	g_return_val_if_fail (group_name != NULL, FALSE);
#line 120 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	g_return_val_if_fail (key_name != NULL, FALSE);
#line 122 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	tmp_key_file = NULL;
#line 123 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	_tmp0_ = key_file;
#line 123 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	if (_tmp0_ == NULL) {
#line 701 "moonshot-settings.c"
		GKeyFile* _tmp1_ = NULL;
		GKeyFile* _tmp2_ = NULL;
#line 125 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp1_ = get_keyfile ();
#line 125 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_g_key_file_unref0 (tmp_key_file);
#line 125 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		tmp_key_file = _tmp1_;
#line 126 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp2_ = tmp_key_file;
#line 126 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		key_file = _tmp2_;
#line 714 "moonshot-settings.c"
	}
#line 129 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	_tmp3_ = key_file;
#line 129 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	if (_tmp3_ == NULL) {
#line 720 "moonshot-settings.c"
		gboolean _tmp4_ = FALSE;
#line 130 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp4_ = _default_;
#line 130 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		result = _tmp4_;
#line 130 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_g_key_file_unref0 (tmp_key_file);
#line 130 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		return result;
#line 730 "moonshot-settings.c"
	}
	{
		gboolean _tmp5_ = FALSE;
		GKeyFile* _tmp6_ = NULL;
		const gchar* _tmp7_ = NULL;
		const gchar* _tmp8_ = NULL;
		gboolean _tmp9_ = FALSE;
#line 133 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp6_ = key_file;
#line 133 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp7_ = group_name;
#line 133 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp8_ = key_name;
#line 133 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp9_ = g_key_file_has_key (_tmp6_, _tmp7_, _tmp8_, &_inner_error_);
#line 133 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp5_ = _tmp9_;
#line 133 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 750 "moonshot-settings.c"
			gboolean _tmp10_ = FALSE;
#line 133 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			if (_inner_error_->domain == G_KEY_FILE_ERROR) {
#line 754 "moonshot-settings.c"
				goto __catch14_g_key_file_error;
			}
#line 133 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			_g_key_file_unref0 (tmp_key_file);
#line 133 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 133 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			g_clear_error (&_inner_error_);
#line 133 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			return _tmp10_;
#line 765 "moonshot-settings.c"
		}
#line 133 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		if (!_tmp5_) {
#line 769 "moonshot-settings.c"
			MoonshotLogger* _tmp11_ = NULL;
			MoonshotLogger* _tmp12_ = NULL;
			const gchar* _tmp13_ = NULL;
			const gchar* _tmp14_ = NULL;
			const gchar* _tmp15_ = NULL;
			const gchar* _tmp16_ = NULL;
			gchar* _tmp17_ = NULL;
			gchar* _tmp18_ = NULL;
			gboolean _tmp19_ = FALSE;
#line 135 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			_tmp11_ = logger ();
#line 135 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			_tmp12_ = _tmp11_;
#line 135 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			_tmp13_ = key_name;
#line 135 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			_tmp14_ = string_to_string (_tmp13_);
#line 135 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			_tmp15_ = group_name;
#line 135 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			_tmp16_ = string_to_string (_tmp15_);
#line 135 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			_tmp17_ = g_strconcat ("get_bool_setting : key file doesn't contain key '", _tmp14_, "' in group '", _tmp16_, "'", NULL);
#line 135 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			_tmp18_ = _tmp17_;
#line 135 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			moonshot_logger_info (_tmp12_, _tmp18_, NULL);
#line 135 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			_g_free0 (_tmp18_);
#line 135 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			_g_object_unref0 (_tmp12_);
#line 136 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			_tmp19_ = _default_;
#line 136 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			result = _tmp19_;
#line 136 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			_g_key_file_unref0 (tmp_key_file);
#line 136 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			return result;
#line 809 "moonshot-settings.c"
		}
	}
	goto __finally14;
	__catch14_g_key_file_error:
	{
		GError* e = NULL;
		MoonshotLogger* _tmp20_ = NULL;
		MoonshotLogger* _tmp21_ = NULL;
		const gchar* _tmp22_ = NULL;
		const gchar* _tmp23_ = NULL;
		const gchar* _tmp24_ = NULL;
		const gchar* _tmp25_ = NULL;
		gchar* _tmp26_ = NULL;
		gchar* _tmp27_ = NULL;
		GError* _tmp28_ = NULL;
		const gchar* _tmp29_ = NULL;
		gchar* _tmp30_ = NULL;
		gchar* _tmp31_ = NULL;
#line 132 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		e = _inner_error_;
#line 132 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_inner_error_ = NULL;
#line 140 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp20_ = logger ();
#line 140 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp21_ = _tmp20_;
#line 140 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp22_ = key_name;
#line 140 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp23_ = string_to_string (_tmp22_);
#line 140 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp24_ = group_name;
#line 140 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp25_ = string_to_string (_tmp24_);
#line 140 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp26_ = g_strconcat ("get_bool_setting : KeyFileError checking if key '", _tmp23_, "' exists in group '", _tmp25_, "' (maybe ignorable?) : ", NULL);
#line 140 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp27_ = _tmp26_;
#line 140 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp28_ = e;
#line 140 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp29_ = _tmp28_->message;
#line 140 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp30_ = g_strconcat (_tmp27_, _tmp29_, NULL);
#line 140 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp31_ = _tmp30_;
#line 140 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		moonshot_logger_info (_tmp21_, _tmp31_, NULL);
#line 140 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_g_free0 (_tmp31_);
#line 140 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_g_free0 (_tmp27_);
#line 140 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_g_object_unref0 (_tmp21_);
#line 132 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_g_error_free0 (e);
#line 866 "moonshot-settings.c"
	}
	__finally14:
#line 132 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 871 "moonshot-settings.c"
		gboolean _tmp32_ = FALSE;
#line 132 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_g_key_file_unref0 (tmp_key_file);
#line 132 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 132 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		g_clear_error (&_inner_error_);
#line 132 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		return _tmp32_;
#line 881 "moonshot-settings.c"
	}
	{
		gboolean _tmp33_ = FALSE;
		GKeyFile* _tmp34_ = NULL;
		const gchar* _tmp35_ = NULL;
		const gchar* _tmp36_ = NULL;
		gboolean _tmp37_ = FALSE;
#line 145 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp34_ = key_file;
#line 145 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp35_ = group_name;
#line 145 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp36_ = key_name;
#line 145 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp37_ = g_key_file_get_boolean (_tmp34_, _tmp35_, _tmp36_, &_inner_error_);
#line 145 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp33_ = _tmp37_;
#line 145 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 901 "moonshot-settings.c"
			gboolean _tmp38_ = FALSE;
#line 145 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			if (_inner_error_->domain == G_KEY_FILE_ERROR) {
#line 905 "moonshot-settings.c"
				goto __catch15_g_key_file_error;
			}
#line 145 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			_g_key_file_unref0 (tmp_key_file);
#line 145 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 145 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			g_clear_error (&_inner_error_);
#line 145 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			return _tmp38_;
#line 916 "moonshot-settings.c"
		}
#line 145 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		result = _tmp33_;
#line 145 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_g_key_file_unref0 (tmp_key_file);
#line 145 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		return result;
#line 924 "moonshot-settings.c"
	}
	goto __finally15;
	__catch15_g_key_file_error:
	{
		GError* e = NULL;
		MoonshotLogger* _tmp39_ = NULL;
		MoonshotLogger* _tmp40_ = NULL;
		GError* _tmp41_ = NULL;
		const gchar* _tmp42_ = NULL;
		gchar* _tmp43_ = NULL;
		gchar* _tmp44_ = NULL;
#line 143 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		e = _inner_error_;
#line 143 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_inner_error_ = NULL;
#line 148 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp39_ = logger ();
#line 148 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp40_ = _tmp39_;
#line 148 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp41_ = e;
#line 148 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp42_ = _tmp41_->message;
#line 148 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp43_ = g_strconcat ("get_bool_setting got KeyFileError (may be ignorable) : ", _tmp42_, NULL);
#line 148 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp44_ = _tmp43_;
#line 148 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		moonshot_logger_info (_tmp40_, _tmp44_, NULL);
#line 148 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_g_free0 (_tmp44_);
#line 148 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_g_object_unref0 (_tmp40_);
#line 143 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_g_error_free0 (e);
#line 960 "moonshot-settings.c"
	}
	__finally15:
#line 143 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 965 "moonshot-settings.c"
		gboolean _tmp45_ = FALSE;
#line 143 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_g_key_file_unref0 (tmp_key_file);
#line 143 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 143 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		g_clear_error (&_inner_error_);
#line 143 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		return _tmp45_;
#line 975 "moonshot-settings.c"
	}
#line 150 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	_tmp46_ = _default_;
#line 150 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	result = _tmp46_;
#line 150 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	_g_key_file_unref0 (tmp_key_file);
#line 150 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	return result;
#line 985 "moonshot-settings.c"
}


void set_string_setting (const gchar* group_name, const gchar* key_name, const gchar* value, GKeyFile* key_file) {
	GKeyFile* tmp_key_file = NULL;
	GKeyFile* _tmp0_ = NULL;
	GKeyFile* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
	GKeyFile* _tmp7_ = NULL;
#line 154 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	g_return_if_fail (group_name != NULL);
#line 154 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	g_return_if_fail (key_name != NULL);
#line 154 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	g_return_if_fail (value != NULL);
#line 156 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	tmp_key_file = NULL;
#line 157 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	_tmp0_ = key_file;
#line 157 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	if (_tmp0_ == NULL) {
#line 1009 "moonshot-settings.c"
		GKeyFile* _tmp1_ = NULL;
		GKeyFile* _tmp2_ = NULL;
#line 159 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp1_ = get_keyfile ();
#line 159 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_g_key_file_unref0 (tmp_key_file);
#line 159 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		tmp_key_file = _tmp1_;
#line 160 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp2_ = tmp_key_file;
#line 160 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		key_file = _tmp2_;
#line 1022 "moonshot-settings.c"
	}
#line 163 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	_tmp3_ = key_file;
#line 163 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	_tmp4_ = group_name;
#line 163 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	_tmp5_ = key_name;
#line 163 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	_tmp6_ = value;
#line 163 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	g_key_file_set_string (_tmp3_, _tmp4_, _tmp5_, _tmp6_);
#line 164 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	_tmp7_ = tmp_key_file;
#line 164 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	if (_tmp7_ != NULL) {
#line 1038 "moonshot-settings.c"
		GKeyFile* _tmp8_ = NULL;
#line 166 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp8_ = key_file;
#line 166 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		save_keyfile (_tmp8_);
#line 1044 "moonshot-settings.c"
	}
#line 154 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	_g_key_file_unref0 (tmp_key_file);
#line 1048 "moonshot-settings.c"
}


gchar* get_string_setting (const gchar* group_name, const gchar* key_name, const gchar* _default_, GKeyFile* key_file) {
	gchar* result = NULL;
	GKeyFile* tmp_key_file = NULL;
	GKeyFile* _tmp0_ = NULL;
	GKeyFile* _tmp3_ = NULL;
	const gchar* _tmp45_ = NULL;
	gchar* _tmp46_ = NULL;
	GError * _inner_error_ = NULL;
#line 170 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	g_return_val_if_fail (group_name != NULL, NULL);
#line 170 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	g_return_val_if_fail (key_name != NULL, NULL);
#line 170 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	g_return_val_if_fail (_default_ != NULL, NULL);
#line 172 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	tmp_key_file = NULL;
#line 173 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	_tmp0_ = key_file;
#line 173 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	if (_tmp0_ == NULL) {
#line 1072 "moonshot-settings.c"
		GKeyFile* _tmp1_ = NULL;
		GKeyFile* _tmp2_ = NULL;
#line 175 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp1_ = get_keyfile ();
#line 175 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_g_key_file_unref0 (tmp_key_file);
#line 175 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		tmp_key_file = _tmp1_;
#line 176 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp2_ = tmp_key_file;
#line 176 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		key_file = _tmp2_;
#line 1085 "moonshot-settings.c"
	}
#line 179 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	_tmp3_ = key_file;
#line 179 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	if (_tmp3_ == NULL) {
#line 1091 "moonshot-settings.c"
		const gchar* _tmp4_ = NULL;
		gchar* _tmp5_ = NULL;
#line 180 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp4_ = _default_;
#line 180 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp5_ = g_strdup (_tmp4_);
#line 180 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		result = _tmp5_;
#line 180 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_g_key_file_unref0 (tmp_key_file);
#line 180 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		return result;
#line 1104 "moonshot-settings.c"
	}
	{
		gboolean _tmp6_ = FALSE;
		GKeyFile* _tmp7_ = NULL;
		const gchar* _tmp8_ = NULL;
		const gchar* _tmp9_ = NULL;
		gboolean _tmp10_ = FALSE;
#line 183 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp7_ = key_file;
#line 183 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp8_ = group_name;
#line 183 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp9_ = key_name;
#line 183 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp10_ = g_key_file_has_key (_tmp7_, _tmp8_, _tmp9_, &_inner_error_);
#line 183 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp6_ = _tmp10_;
#line 183 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 183 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			if (_inner_error_->domain == G_KEY_FILE_ERROR) {
#line 1126 "moonshot-settings.c"
				goto __catch16_g_key_file_error;
			}
#line 183 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			_g_key_file_unref0 (tmp_key_file);
#line 183 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 183 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			g_clear_error (&_inner_error_);
#line 183 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			return NULL;
#line 1137 "moonshot-settings.c"
		}
#line 183 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		if (!_tmp6_) {
#line 1141 "moonshot-settings.c"
			MoonshotLogger* _tmp11_ = NULL;
			MoonshotLogger* _tmp12_ = NULL;
			const gchar* _tmp13_ = NULL;
			const gchar* _tmp14_ = NULL;
			const gchar* _tmp15_ = NULL;
			const gchar* _tmp16_ = NULL;
			gchar* _tmp17_ = NULL;
			gchar* _tmp18_ = NULL;
			const gchar* _tmp19_ = NULL;
			gchar* _tmp20_ = NULL;
#line 185 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			_tmp11_ = logger ();
#line 185 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			_tmp12_ = _tmp11_;
#line 185 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			_tmp13_ = key_name;
#line 185 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			_tmp14_ = string_to_string (_tmp13_);
#line 185 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			_tmp15_ = group_name;
#line 185 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			_tmp16_ = string_to_string (_tmp15_);
#line 185 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			_tmp17_ = g_strconcat ("get_string_setting : key file doesn't contain key '", _tmp14_, "' in group '", _tmp16_, "'", NULL);
#line 185 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			_tmp18_ = _tmp17_;
#line 185 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			moonshot_logger_info (_tmp12_, _tmp18_, NULL);
#line 185 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			_g_free0 (_tmp18_);
#line 185 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			_g_object_unref0 (_tmp12_);
#line 186 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			_tmp19_ = _default_;
#line 186 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			_tmp20_ = g_strdup (_tmp19_);
#line 186 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			result = _tmp20_;
#line 186 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			_g_key_file_unref0 (tmp_key_file);
#line 186 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			return result;
#line 1184 "moonshot-settings.c"
		}
	}
	goto __finally16;
	__catch16_g_key_file_error:
	{
		GError* e = NULL;
		MoonshotLogger* _tmp21_ = NULL;
		MoonshotLogger* _tmp22_ = NULL;
		const gchar* _tmp23_ = NULL;
		const gchar* _tmp24_ = NULL;
		const gchar* _tmp25_ = NULL;
		const gchar* _tmp26_ = NULL;
		gchar* _tmp27_ = NULL;
		gchar* _tmp28_ = NULL;
		GError* _tmp29_ = NULL;
		const gchar* _tmp30_ = NULL;
		gchar* _tmp31_ = NULL;
		gchar* _tmp32_ = NULL;
#line 182 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		e = _inner_error_;
#line 182 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_inner_error_ = NULL;
#line 190 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp21_ = logger ();
#line 190 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp22_ = _tmp21_;
#line 190 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp23_ = key_name;
#line 190 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp24_ = string_to_string (_tmp23_);
#line 190 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp25_ = group_name;
#line 190 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp26_ = string_to_string (_tmp25_);
#line 190 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp27_ = g_strconcat ("get_string_setting : KeyFileError checking if key '", _tmp24_, "' exists in group '", _tmp26_, "' (maybe ignorable?) : ", NULL);
#line 190 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp28_ = _tmp27_;
#line 190 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp29_ = e;
#line 190 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp30_ = _tmp29_->message;
#line 190 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp31_ = g_strconcat (_tmp28_, _tmp30_, NULL);
#line 190 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp32_ = _tmp31_;
#line 190 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		moonshot_logger_info (_tmp22_, _tmp32_, NULL);
#line 190 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_g_free0 (_tmp32_);
#line 190 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_g_free0 (_tmp28_);
#line 190 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_g_object_unref0 (_tmp22_);
#line 182 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_g_error_free0 (e);
#line 1241 "moonshot-settings.c"
	}
	__finally16:
#line 182 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 182 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_g_key_file_unref0 (tmp_key_file);
#line 182 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 182 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		g_clear_error (&_inner_error_);
#line 182 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		return NULL;
#line 1254 "moonshot-settings.c"
	}
	{
		gchar* _tmp33_ = NULL;
		GKeyFile* _tmp34_ = NULL;
		const gchar* _tmp35_ = NULL;
		const gchar* _tmp36_ = NULL;
		gchar* _tmp37_ = NULL;
		gchar* _tmp38_ = NULL;
#line 195 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp34_ = key_file;
#line 195 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp35_ = group_name;
#line 195 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp36_ = key_name;
#line 195 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp37_ = g_key_file_get_string (_tmp34_, _tmp35_, _tmp36_, &_inner_error_);
#line 195 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp33_ = _tmp37_;
#line 195 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 195 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			if (_inner_error_->domain == G_KEY_FILE_ERROR) {
#line 1277 "moonshot-settings.c"
				goto __catch17_g_key_file_error;
			}
#line 195 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			_g_key_file_unref0 (tmp_key_file);
#line 195 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 195 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			g_clear_error (&_inner_error_);
#line 195 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
			return NULL;
#line 1288 "moonshot-settings.c"
		}
#line 195 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp38_ = _tmp33_;
#line 195 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp33_ = NULL;
#line 195 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		result = _tmp38_;
#line 195 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_g_free0 (_tmp33_);
#line 195 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_g_key_file_unref0 (tmp_key_file);
#line 195 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		return result;
#line 1302 "moonshot-settings.c"
	}
	goto __finally17;
	__catch17_g_key_file_error:
	{
		GError* e = NULL;
		MoonshotLogger* _tmp39_ = NULL;
		MoonshotLogger* _tmp40_ = NULL;
		GError* _tmp41_ = NULL;
		const gchar* _tmp42_ = NULL;
		gchar* _tmp43_ = NULL;
		gchar* _tmp44_ = NULL;
#line 193 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		e = _inner_error_;
#line 193 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_inner_error_ = NULL;
#line 198 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp39_ = logger ();
#line 198 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp40_ = _tmp39_;
#line 198 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp41_ = e;
#line 198 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp42_ = _tmp41_->message;
#line 198 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp43_ = g_strconcat ("get_string_setting got KeyFileError (may be ignorable) : ", _tmp42_, NULL);
#line 198 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_tmp44_ = _tmp43_;
#line 198 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		moonshot_logger_info (_tmp40_, _tmp44_, NULL);
#line 198 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_g_free0 (_tmp44_);
#line 198 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_g_object_unref0 (_tmp40_);
#line 193 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_g_error_free0 (e);
#line 1338 "moonshot-settings.c"
	}
	__finally17:
#line 193 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 193 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		_g_key_file_unref0 (tmp_key_file);
#line 193 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 193 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		g_clear_error (&_inner_error_);
#line 193 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
		return NULL;
#line 1351 "moonshot-settings.c"
	}
#line 200 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	_tmp45_ = _default_;
#line 200 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	_tmp46_ = g_strdup (_tmp45_);
#line 200 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	result = _tmp46_;
#line 200 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	_g_key_file_unref0 (tmp_key_file);
#line 200 "/home/hartmans/moonshot/moonshot/ui/src/moonshot-settings.vala"
	return result;
#line 1363 "moonshot-settings.c"
}



